# Change Log

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](http://keepachangelog.com/)
and this project adheres to [Semantic Versioning](http://semver.org/).


## [In Development] - Unreleased


## [0.0.2] - 2022-09-18

### Added

- Hint text to the "Announcement Text" field with a link to Discord Markdown

### Removed

- Deprecated attributes from `style` and `script` tags


## [0.0.1] - 2022-08-08

### Added

- First public version
